## cdist-type__package_pacman(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__package_pacman - Manage packages with pacman

## 2. DESCRIPTION

Pacman is usually used on the Archlinux distribution to manage packages.

## 3. REQUIRED PARAMETERS

None

## 4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present"

## 5. EXAMPLES

    # Ensure zsh in installed
    __package_pacman zsh --state present

    # If you don't want to follow pythonX packages, but always use python
    __package_pacman python --state present --name python2

    # Remove obsolete package
    __package_pacman puppet --state absent

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__package(7)

## 7. COPYING

Copyright (C) 2011-2012 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).